@@ -8,11 +8,13 @@ use warnings;
 use DateTime;
 use DateTime::Format::Human::Duration;
 
-our $VERSION = '1.19'; # VERSION
+our $VERSION = '1.20'; # VERSION
 
 sub init {
-    my ($bot) = @_;
-    my $greeting = $bot->vars // 'greetings';
+    my ($bot)    = @_;
+    my $vars     = $bot->vars;
+    my $greeting = ( not ref $vars ) ? $vars : $vars->{greeting} // 'greetings';
+    my $channels = ( ref $vars ) ? $vars->{channels} : undef;
 
     $bot->hook(
         {
@@ -20,32 +22,13 @@ sub init {
         },
         sub {
             my ( $bot, $in ) = @_;
-            $bot->reply_to( greeting_based_on_nick( $greeting, $in->{nick} ) );
-            return;
-        },
-    );
 
-    $bot->hook(
-        {
-            to_me => 1,
-            text  => greeting_based_on_nick( $greeting, $bot->nick ),
+            unless ( ref $channels and not grep { $_ eq $in->{forum} } @$channels ) {
+                $bot->reply_to( greeting_based_on_nick( $greeting, $in->{nick} ) );
+                return;
+            }
         },
-        sub {
-            my ( $bot, $in ) = @_;
-            $bot->reply_to('Thanks.');
-        },
-    );
-
-    $bot->hook(
-        {
-            to_me => 1,
-            text  => 'Thanks.',
-        },
-        sub {
-            my ( $bot, $in ) = @_;
-            $bot->reply_to(q{You're welcome.});
-        },
-    );
+    ) unless ( defined $channels and not ref $channels and $channels == 0 );
 }
 
 sub greeting_based_on_nick {
@@ -80,7 +63,7 @@ Bot::IRC::Greeting - Bot::IRC greet joining users to channels
 
 =head1 VERSION
 
-version 1.19
+version 1.20
 
 =head1 SYNOPSIS
 
@@ -89,7 +72,12 @@ version 1.19
     Bot::IRC->new(
         connect => { server => 'irc.perl.org' },
         plugins => ['Greeting'],
-        vars    => { greeting => 'morning' },
+        vars    => {
+            greeting => {
+                greeting => 'morning',
+                channels => [ '#perl', '#perl-help' ],
+            },
+        },
     )->run;
 
 =head1 DESCRIPTION
@@ -100,7 +88,15 @@ will change the style of "greetings" to somewhat match the user's nick style.
 For example, if "John" joins, the bot will say "Greetings" to him. If
 "joan_" joins, the bot will say "greetings_" to her.
 
-You can specify the greeting word with C<vars>, C<greeting>.
+You can specify the greeting word and channel list with C<vars>.
+
+    greeting => 'morning',
+    channels => [ '#perl', '#perl-help' ],
+
+If greeting isn't specified, the bot will use "greetings" as the greeting. If
+a channel list isn't supplied, the bot will greet on all channels it's on. If
+you specify a greeting of empty string or some other false value, the greeting
+will get skipped.
 
 =head2 SEE ALSO
 
@@ -114,7 +110,7 @@ Gryphon Shafer <gryphon@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Gryphon Shafer.
+This software is copyright (c) 2018 by Gryphon Shafer.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
